/*
 * Copyright (c) 2011 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */
package org.dive4elements.artifactdatabase;

import java.util.LinkedList;

import org.apache.log4j.Logger;
import org.dive4elements.artifacts.ArtifactCollection;
import org.dive4elements.artifacts.CallMeta;
import org.dive4elements.artifacts.Message;

/**
 * Class that implements the call context handed to ArtifactCollection specific
 * operations.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class CollectionCallContext extends AbstractCallContext {

    private static Logger log = Logger.getLogger(CollectionCallContext.class);

    /**
     * The ArtifactCollection.
     */
    private final ArtifactCollection collection;

    public CollectionCallContext(final ArtifactDatabaseImpl artifactDatabase, final int action, final CallMeta callMeta, final ArtifactCollection collection) {
        super(artifactDatabase, action, callMeta);

        this.collection = collection;
    }

    public ArtifactCollection getCollection() {
        return this.collection;
    }

    @Override
    public void afterCall(final int action) {
        log.debug("CollectionCallContext.afterCall - NOT IMPLEMENTED");
    }

    @Override
    public void afterBackground(final int action) {
        log.debug("CollectionCallContext.afterBackground - NOT IMPLEMENTED");
    }

    @Override
    public boolean isInBackground() {
        log.debug("CollectionCallContext.isInBackground - NOT IMPLEMENTED");
        return false;
    }

    @Override
    public void addBackgroundMessage(final Message msg) {
        log.debug("CollectionCallContext.addBackgroundMessage NOT IMPLEMENTED");
    }

    @Override
    public LinkedList<Message> getBackgroundMessages() {
        log.debug("CollectionCallContext.addBackgroundMessage NOT IMPLEMENTED");
        return null;
    }

    @Override
    public Long getTimeToLive() {
        log.debug("CollectionCallContext.getTimeToLive - NOT IMPLEMENTED");
        return null;
    }
}